from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="smart-energy-manager-lib",
    version="1.2.0",
    author="Smart Energy Platform",
    author_email="projectwebx11@gmail.com",
    description="Generic library for energy management and peer-to-peer trading",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/x24250511/smart-energy-platform",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.8",
    keywords="energy solar renewable trading p2p",
)
